==> jc-1.4.0.tar.gz: gnu/java/security/x509/ext/GeneralNames.h <==
// public class gnu.java.security.x509.ext.GeneralNames

// class file dependencies
// @dep_class aea4e8787bb9f71b gnu_java_security_x509_ext_GeneralNames
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_x509_ext_GeneralNames_H_
#define _JC_gnu_java_security_x509_ext_GeneralNames_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_GeneralNames$sub_refs	_jc_gnu_java_security_x509_ext_GeneralNames$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_GeneralNames$sub_nonrefs	_jc_gnu_java_security_x509_ext_GeneralNames$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_GeneralNames$refs	_jc_gnu_java_security_x509_ext_GeneralNames$refs;
typedef struct _jc_gnu_java_security_x509_ext_GeneralNames$nonrefs	_jc_gnu_java_security_x509_ext_GeneralNames$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_GeneralNames$object	_jc_gnu_java_security_x509_ext_GeneralNames$object;

typedef struct _jc_gnu_java_security_x509_ext_GeneralNames$fields_struct	_jc_gnu_java_security_x509_ext_GeneralNames$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_GeneralNames$vmethods	_jc_gnu_java_security_x509_ext_GeneralNames$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_GeneralNames$vtable	_jc_gnu_java_security_x509_ext_GeneralNames$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_GeneralNames$vtype	_jc_gnu_java_security_x509_ext_GeneralNames$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_GeneralNames$fields_struct {
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24GeneralNames;
	jint	DIRECTORY__5fNAME;
	jint	DNS__5fNAME;
	jint	EDI__5fPARTY__5fNAME;
	jint	IP__5fADDRESS;
	jint	OTHER__5fNAME;
	jint	REGISTERED__5fID;
	jint	RFC822__5fNAME;
	jint	URI;
	jint	X400__5fADDRESS;
};
extern _jc_gnu_java_security_x509_ext_GeneralNames$fields_struct _jc_gnu_java_security_x509_ext_GeneralNames$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_GeneralNames$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_GeneralNames$object *, struct _jc_byte_array *);

// Virtual methods
extern struct _jc_object *_jc_gnu_java_security_x509_ext_GeneralNames$method$getNames$d565a0d1c278ffb5(_jc_env *, struct _jc_gnu_java_security_x509_ext_GeneralNames$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_GeneralNames$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_GeneralNames$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_GeneralNames$method_info$getNames$d565a0d1c278ffb5;
extern _jc_method _jc_gnu_java_security_x509_ext_GeneralNames$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_GeneralNames$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_GeneralNames$vmethods {
	struct _jc_object	*(*getNames$d565a0d1c278ffb5)(_jc_env *, struct _jc_gnu_java_security_x509_ext_GeneralNames$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_GeneralNames$object *);
};

// Vtable
struct _jc_gnu_java_security_x509_ext_GeneralNames$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_GeneralNames$vmethods	gnu_java_security_x509_ext_GeneralNames;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_GeneralNames$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_GeneralNames$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_GeneralNames$sub_refs {
	struct _jc_object	*names;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_GeneralNames$refs {
    _jc_gnu_java_security_x509_ext_GeneralNames$sub_refs	gnu_java_security_x509_ext_GeneralNames;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_GeneralNames$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_GeneralNames$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_GeneralNames$sub_nonrefs	gnu_java_security_x509_ext_GeneralNames;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_GeneralNames$object {
	_jc_gnu_java_security_x509_ext_GeneralNames$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_GeneralNames$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_GeneralNames$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_GeneralNames$vtype _jc_gnu_java_security_x509_ext_GeneralNames$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_GeneralNames, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_GeneralNames$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_GeneralNames_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/x509/ext/GeneralNames.h <==
// public class gnu.java.security.x509.ext.GeneralNames

// class file dependencies
// @dep_class da8ef49fc66ec243 gnu_java_security_x509_ext_GeneralNames
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_x509_ext_GeneralNames_H_
#define _JC_gnu_java_security_x509_ext_GeneralNames_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_GeneralNames$sub_refs	_jc_gnu_java_security_x509_ext_GeneralNames$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_GeneralNames$sub_nonrefs	_jc_gnu_java_security_x509_ext_GeneralNames$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_GeneralNames$refs	_jc_gnu_java_security_x509_ext_GeneralNames$refs;
typedef struct _jc_gnu_java_security_x509_ext_GeneralNames$nonrefs	_jc_gnu_java_security_x509_ext_GeneralNames$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_GeneralNames$object	_jc_gnu_java_security_x509_ext_GeneralNames$object;

typedef struct _jc_gnu_java_security_x509_ext_GeneralNames$fields_struct	_jc_gnu_java_security_x509_ext_GeneralNames$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_GeneralNames$vmethods	_jc_gnu_java_security_x509_ext_GeneralNames$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_GeneralNames$vtable	_jc_gnu_java_security_x509_ext_GeneralNames$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_GeneralNames$vtype	_jc_gnu_java_security_x509_ext_GeneralNames$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_GeneralNames$fields_struct {
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24GeneralNames;
	jint	DIRECTORY__5fNAME;
	jint	DNS__5fNAME;
	jint	EDI__5fPARTY__5fNAME;
	jint	IP__5fADDRESS;
	jint	OTHER__5fNAME;
	jint	REGISTERED__5fID;
	jint	RFC822__5fNAME;
	jint	URI;
	jint	X400__5fADDRESS;
};
extern _jc_gnu_java_security_x509_ext_GeneralNames$fields_struct _jc_gnu_java_security_x509_ext_GeneralNames$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_GeneralNames$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_GeneralNames$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_gnu_java_security_x509_ext_GeneralNames$method$getNames$d565a0d1c278ffb5(_jc_env *, struct _jc_gnu_java_security_x509_ext_GeneralNames$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_GeneralNames$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_GeneralNames$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_GeneralNames$method_info$getNames$d565a0d1c278ffb5;
extern _jc_method _jc_gnu_java_security_x509_ext_GeneralNames$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_GeneralNames$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_GeneralNames$vmethods {
	struct _jc_object	*(*getNames$d565a0d1c278ffb5)(_jc_env *, struct _jc_gnu_java_security_x509_ext_GeneralNames$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_GeneralNames$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_x509_ext_GeneralNames$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_GeneralNames$vmethods	gnu_java_security_x509_ext_GeneralNames;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_GeneralNames$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_GeneralNames$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_GeneralNames$sub_refs {
	struct _jc_object	*names;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_GeneralNames$refs {
    _jc_gnu_java_security_x509_ext_GeneralNames$sub_refs	gnu_java_security_x509_ext_GeneralNames;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_GeneralNames$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_GeneralNames$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_GeneralNames$sub_nonrefs	gnu_java_security_x509_ext_GeneralNames;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_GeneralNames$object {
	_jc_gnu_java_security_x509_ext_GeneralNames$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_GeneralNames$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_GeneralNames$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_GeneralNames$vtype _jc_gnu_java_security_x509_ext_GeneralNames$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_GeneralNames, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_GeneralNames$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_GeneralNames_H_ */
